Header

Struct Header 

pub struct Header {
    pub transaction_id: u16,
    pub protocol_id: u16,
    pub length: u16,
    pub unit_id: UnitId,
}
Modbus Application Protocol (Data Unit) header aka «MBAP header».

Fields

transaction_id: u16

Transaction ID used to match responses with requests.

protocol_id: u16

Protocol ID. Always 0 for Modbus.

length: u16

Number of following codec, including the Unit Identifier and data fields.

unit_id: UnitId

Unit identifier aka «slave ID».

Identification of a remote slave connected on a serial line or on other buses.

Implementations

Source

impl Header

pub const N_BYTES: usize = 7

pub const fn payload_length(&self) -> u16

Expected PDU length.

TCP transport implementation should read exactly this number of codec and parse as crate::protocol::Response.

Source

impl Header

pub const PROTOCOL_ID: u16 = 0