pub enum Exception {
IllegalFunction,
IllegalDataAddress,
IllegalDataValue,
ServerDeviceFailure,
Acknowledge,
ServerDeviceBusy,
MemoryParityError,
GatewayPathUnavailable,
GatewayTargetDeviceFailedToRespond,
Custom(u8),
}Expand description
High-level protocol error.
The server received the request without a communication error, but could not handle it.
Variants
IllegalFunction
The function code received in the query is not an allowable action for the server:
- the function was not implemented in the unit selected;
- the server is in the wrong state to process a request of this type.
IllegalDataAddress
The data address received in the query is not an allowable address for the server.
The combination of reference number and transfer length is invalid.
IllegalDataValue
A value contained in the query data field is not an allowable value for server.
ServerDeviceFailure
An unrecoverable error occurred while the server was attempting to perform the requested action.
Acknowledge
The server has accepted the request and is processing it, but a long duration of time will be required to do so.
This response is returned to prevent a timeout error from occurring in the client. The client can next issue a «Poll Program Complete» message to determine if processing is completed.
ServerDeviceBusy
The server is engaged in processing a long–duration program command.
The client should retransmit the message later when the server is free.
MemoryParityError
The server attempted to read record file, but detected a parity error in the memory.
The client can retry the request, but service may be required on the server device.
The gateway was unable to allocate an internal communication path from the input port to the output port for processing the request.
GatewayTargetDeviceFailedToRespond
No response was obtained from the target device.
Usually means that the device is not present on the network.
Custom(u8)
Non-standard error code.