pub trait Function: Code {
type Args: Encode;
type Output: Decode + IntoValue;
}Expand description
Trait that ties function code, arguments and output together.
Users are free to implement their own functions – be that custom Modbus functions or alternate standard function implementations. In the latter case, consider making a pull request.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.